import { ValueOrPromise } from '@loopback/core';
import { RequestContext } from '@loopback/rest';
/**
 * Information about a tenant in the multi-tenancy environment
 */
export interface Tenant {
    id: string;
    [attribute: string]: unknown;
}
/**
 * Resolve a tenant for the given request
 */
export interface MultiTenancyAction {
    (requestContext: RequestContext): ValueOrPromise<Tenant | undefined>;
}
export interface MultiTenancyActionOptions {
    strategyNames: string[];
}
/**
 * Interface for a multi-tenancy strategy to implement
 */
export interface MultiTenancyStrategy {
    /**
     * Name of the strategy
     */
    name: string;
    /**
     * Identify the tenant for a given http request
     * @param requestContext - Http request
     */
    identifyTenant(requestContext: RequestContext): ValueOrPromise<Tenant | undefined>;
    /**
     * Bind tenant-specific resources for downstream artifacts with dependency
     * injection
     * @param requestContext - Request context
     */
    bindResources(requestContext: RequestContext, tenant: Tenant): ValueOrPromise<void>;
}
